import React, { useState } from 'react'
import { useTranslation } from 'react-i18next'

import { appTheme, appTimezone, appVersion, appInst } from 'appConfig'

export const Debug = () => {
  const [apiHealth, setApiHealth] = useState('not yet')
  const [didContactApi, setDidContactApi] = useState(false)
  const { i18n } = useTranslation(['common'])
  const [csrf, setCsrf] = useState<String | null>(null)
  const [isAuthenticated, setIsAuthenticated] = useState(false)
  const [username, setUsername] = useState(undefined)

  if (!didContactApi) {
    setDidContactApi(true)
    fetch('http://localhost:3000/api/health/')
      .then((res) => res.text())
      .then((result) => {
        if (result === 'OK') {
          setApiHealth('yes')
        } else {
          setApiHealth(result)
        }
      })
      // eslint-disable-next-line @typescript-eslint/no-unused-vars
      .catch((error) => {
        setApiHealth('error')
      })
  }

  const getCSRF = () => {
    fetch('/api/ui/v1/csrf/', {
      credentials: 'same-origin',
    })
      .then((res) => {
        const csrfToken = res.headers.get('X-CSRFToken')
        setCsrf(csrfToken)
        console.log(csrfToken)
      })
      .catch((err) => {
        console.log(err)
      })
  }

  const getSession = () => {
    fetch('/api/ui/v1/session/?format=json', {
      headers: {
        'Content-Type': 'application/json',
      },
      credentials: 'same-origin',
    })
      .then((res) => res.json())
      .then((data) => {
        console.log(data)
        if (data.isAuthenticated) {
          setIsAuthenticated(true)
        } else {
          setIsAuthenticated(false)
          getCSRF()
        }
      })
      .catch((err) => {
        setIsAuthenticated(false)
        console.log(err)
      })
  }

  const whoami = () => {
    fetch('/api/ui/v1/whoami/', {
      headers: {
        'Content-Type': 'application/json',
      },
      credentials: 'same-origin',
    })
      .then((res) => res.json())
      .then((data) => {
        setUsername(data.username)
        console.log(`You are logged in as: ${data.username}`)
      })
      .catch((err) => {
        console.log(err)
      })
  }

  function isResponseOk(response: any) {
    if (response.status >= 200 && response.status <= 299) {
      return response.json()
    }
    throw Error(response.statusText)
  }

  const logout = () => {
    fetch('/api/ui/v1/logout/', {
      credentials: 'same-origin',
    })
      .then(isResponseOk)
      .then((data) => {
        console.log(data)
        setIsAuthenticated(false)
        getCSRF()
      })
      .catch((err) => {
        console.log(err)
      })
  }

  const d = [
    ['NODE_ENV', process.env.NODE_ENV],
    ['Version', appVersion],
    ['Timezone', appTimezone],
    ['Language', i18n.language],
    ['Theme', appTheme],
    ['Institution', appInst],
    ['API reachable?', apiHealth],
    ['Csrf', csrf],
    ['Authenticated?', isAuthenticated ? 'Authenticated' : 'Not Authenticated'],
    ['username', username],
  ]
  return (
    <table>
      <thead>
        <strong>Debug</strong>
      </thead>
      <button type="button" onClick={() => getSession()}>
        AM I AUTHENTICATED?
      </button>
      <button type="button" onClick={() => whoami()}>
        WHO AM I?
      </button>
      <button type="button" onClick={() => logout()}>
        LOGOUT
      </button>
      <tbody>
        {d.map(([key, value]) => (
          <tr>
            <td>{key}</td>
            <td>{value}</td>
          </tr>
        ))}
      </tbody>
    </table>
  )
}

export default Debug
