import validator from '@navikt/fnrvalidator'
import i18n from 'i18next'

export function getCookie(name: string) {
  if (!document.cookie) {
    return null
  }

  const cookies = document.cookie
    .split(';')
    .map((c) => c.trim())
    .filter((c) => c.startsWith(`${name}=`))

  if (cookies.length === 0) {
    return null
  }
  return decodeURIComponent(cookies[0].split('=')[1])
}

export function maybeCsrfToken() {
  const csrfToken = getCookie('csrftoken')
  if (!csrfToken) {
    return null
  }
  return {
    'X-CSRFToken': csrfToken,
  }
}

export function postJsonOpts(data: object): RequestInit {
  return {
    method: 'POST',
    headers: {
      'Content-Type': 'application/json',
      ...maybeCsrfToken(),
    },
    body: JSON.stringify(data),
    credentials: 'same-origin',
  }
}

export function isValidFnr(data: string): boolean | string {
  const valid = validator.idnr(data).status === 'valid'
  if (valid) {
    return true
  }
  // TypeScript complains if toString is not used on the function result
  return i18n.t('common:validation.invalidIdNumber').toString()
}
